function model = loadModel(filepath)

% model = loadModel(filepath): Load model
% 
%     Input:
%       filepath - the path for model file
%     Output:
%		model - the 3d model file
%           model.nv: no. of points
%           model.np: no. of parameters
%           model.A: A matrix, contain all points, 3 nv * np
%           model.At: A matrix, 3 * nv np
%           model.Am: A matrix, A(:,:,m) contains info for mth point
%           model.Adjmat: adjacent matrix
%
% Xue Tianfan, <xtf009@ie.cuhk.edu.hk>, MMLab CUHK

% load file
fin = fopen(filepath);
tline = fgetl(fin);

while ~(isnumeric(tline) && tline == -1) && (~isempty(tline))
    words = regexp(tline, ' |\t', 'split');
    if strcmp(words{1}, 'CoorM')
        nv = sscanf(words{2}, '%d')/3;
        np = sscanf(words{3}, '%d');
        A = zeros(nv*3, np);
        for i=1:nv*3
            tline = fgetl(fin);
            idx = strfind(tline, '%');
            if idx ~= -1
                tline = tline(1:(strfind(tline, '%')-1));
            end
            A(i,:) = reshape(sscanf(tline, '%f'), 1, np);
        end
        A = A - repmat(A(1:3,:), nv, 1);
    elseif strcmp(words{1}, 'ConnectM')
        nv = sscanf(words{2}, '%d');
        Adjmat = zeros(nv, nv);
        for i=1:nv
            tline = fgetl(fin);
            idx = strfind(tline, '%');
            if idx ~= -1
                tline = tline(1:(strfind(tline, '%')-1));
            end
            Adjmat(i,:) = reshape(sscanf(tline, '%d'), 1, nv);
        end
    end
    tline = fgetl(fin);
end

Am = zeros(3,np,nv);
At = zeros(3,np*nv);
for i=1:nv
    Am(:,:,i) = A(i*3-2:i*3, :);
    At(:,(i-1)*np+1:i*np) = Am(:,:,i);
end
model = struct('nv', nv, 'np', np, 'A', A, 'Am', Am, 'At', At, 'Adjmat', Adjmat);
fclose(fin);

end







