function obj = load_3drcy_v2(inputfile)

% load_3drcy_v2(): load 3dr file (Chen yu's format)
% 
% obj = load_3drcy_v2(inputfile)
%     Input:
%		inputfile: the path for input file
%     Output:
%       obj.pointList: 2*n, 2d point coor matrix
%       obj.edgeList: 2*m, line map
%       obj.faceList: face i
%           vertexNum, pointList
%
% Xue Tianfan, <xtf009@ie.cuhk.edu.hk>, MMLab CUHK

    fin = fopen(inputfile);
    lineNum = sscanf(fgetl(fin), '%d');
    
    lineMatrix = zeros(lineNum, 4);
    for i = 1:lineNum
        lineMatrix(i,:) = sscanf(fgetl(fin), '%d %d %d %d');
    end

    vertexNum = sscanf(fgetl(fin), '%d');

    vertexMatrix = zeros(vertexNum);
    for i = 1:vertexNum
        tline = fgetl(fin);
        parts = regexp(tline,' |\t','split');
        for j = 1:vertexNum            
            vertexMatrix(i,j) = sscanf(parts{j}, '%d');
        end
    end
    
    faceNum = sscanf(fgetl(fin), '%d');
    faceMatrix = zeros(faceNum, vertexNum * 2 + 2);
    for i = 1:faceNum
        tline = fgetl(fin);
        parts = regexp(tline,' |\t','split');
        for j = 1:length(parts)
            if parts{j} ~= 0
                faceMatrix(i,j) = sscanf(parts{j}, '%d');
            end
        end
    end
    
    fgetl(fin);
    fgetl(fin);
    vertexLineMatrix = zeros(lineNum, 2);
    for i = 1:lineNum
        tline = fgetl(fin);
        parts = regexp(tline,' |\t','split');
        vertexLineMatrix(i,1) = sscanf(parts{1}, '%d');
        vertexLineMatrix(i,2) = sscanf(parts{2}, '%d');
    end
    fclose(fin);
    
    % Create Object
    pointList = zeros(2, vertexNum);
    edgeList = vertexLineMatrix';
    faceList = cell(faceNum, 1);
    % Create PointList
    for i = 1:lineNum
        for j = 1:2
            pIdx = vertexLineMatrix(i, j) + 1;
            pointList(:, pIdx) = [lineMatrix(i, j*2-1); lineMatrix(i, j*2)];
        end
    end
    % Create FaceList
    for i = 1:faceNum
        tmpFace.vertexNum = faceMatrix(i, 1);
        tmpFace.pointList = faceMatrix(i, 2:2+tmpFace.vertexNum) + 1;
        tmpFace.edgeList = faceMatrix(i, tmpFace.vertexNum+3:tmpFace.vertexNum*2+2) + 1;
        faceList{i} = tmpFace;
    end
    
    obj.pointList = pointList;
    obj.edgeList = edgeList+1;
    obj.faceList = faceList;
end




