% plot3dManifold_LM(): display a manifold in 3D space
% 
% plot3dManifold_LM(LineMap, Coor3D)
%     Input:
%       LineMap: LineMap(i,1:2) are the index of begining and end points
%       Coor3D: 3D coordinates of each points
%       WindowName: Figure name
%       Indices: indices to be displayed for each pixel
%     Output:
%
% Xue Tianfan, <xtf009@ie.cuhk.edu.hk>, MMLab CUHK

function plot3dManifold_LM(LineMap, Coor3D, WindowName, Indices)

    if exist('WindowName', 'var') && ~isempty(WindowName)
		tmpH = figure;
		tmpPos = get(tmpH, 'Position');
		set(tmpH, 'Position', [300 400 tmpPos(3:4)]);
        set(tmpH, 'Name', WindowName);
    end
    
    edgeNum = size(LineMap, 2);
    Coor3D(2,:) = -Coor3D(2,:);
    for i=1:edgeNum
        idx = LineMap(:, i);
        plot3(Coor3D(1, idx), Coor3D(2, idx), Coor3D(3, idx));
        hold on;
    end
    pointNum = size(Coor3D, 2);
    if exist('Indices', 'var')
        for i=1:pointNum
            text(Coor3D(1, i), Coor3D(2, i), Coor3D(3, i), int2str(Indices(i)));
        end
    else
        for i=1:pointNum
            text(Coor3D(1, i), Coor3D(2, i), Coor3D(3, i), int2str(i));
        end
    end
    axis equal;

end

